# django-discordbot

[![PyPI](https://img.shields.io/pypi/v/django-discordbot)](https://pypi.org/project/django-discordbot)
![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-discordbot)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-discordbot)
![PyPI - License](https://img.shields.io/pypi/l/django-discordbot)

![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/rafaelurben/django-discordbot)
![GitHub lines of code](https://img.shields.io/tokei/lines/github.com/rafaelurben/django-discordbot)
[![GitHub issues](https://img.shields.io/github/issues/rafaelurben/django-discordbot)](https://github.com/rafaelurben/django-discordbot/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/rafaelurben/django-discordbot)](https://github.com/rafaelurben/django-discordbot/pulls)

[![CodeFactor](https://www.codefactor.io/repository/github/rafaelurben/django-discordbot/badge)](https://www.codefactor.io/repository/github/rafaelurben/django-discordbot)

A Discord bot running in a django environment. The current version of the bot itself is German, but I might consider adding translations in the future.

Planned features can be found in the [project board](https://github.com/rafaelurben/django-discordbot/projects/1?fullscreen=true).

Feel free to open an issue or start a pull request. ;)

## Requirements

Basic Python and Django knowledge.

## Documentation

You can find a documentation in the [docs folder](./docs/index.md).
